@@ -21,7 +21,8 @@ impl SourceTextInfo {
     // existing, but ideally it should be stripped before it
     // gets passed here because it's a text encoding concern
     // that should be stripped when the file is read.
-    debug_assert!(!text.starts_with(BOM_CHAR));
+    // todo(dsherret): re-enable once stripped in deno_graph
+    // debug_assert!(!text.starts_with(BOM_CHAR));
 
     Self::with_indent_width(start_pos, text, 2)
   }
